Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Source file luv_c_type_descriptions.ml
12345678910111213141516171819202122232425262728293031323334353637383940414243444546474849505152535455565758596061626364656667686970717273747576777879808182838485868788899091929394959697989910010110210310410510610710810911011111211311411511611711811912012112212312412512612712812913013113213313413513613713813914014114214314414514614714814915015115215315415515615715815916016116216316416516616716816917017117217317417517617717817918018118218318418518618718818919019119219319419519619719819920020120220320420520620720820921021121221321421521621721821922022122222322422522622722822923023123223323423523623723823924024124224324424524624724824925025125225325425525625725825926026126226326426526626726826927027127227327427527627727827928028128228328428528628728828929029129229329429529629729829930030130230330430530630730830931031131231331431531631731831932032132232332432532632732832933033133233333433533633733833934034134234334434534634734834935035135235335435535635735835936036136236336436536636736836937037137237337437537637737837938038138238338438538638738838939039139239339439539639739839940040140240340440540640740840941041141241341441541641741841942042142242342442542642742842943043143243343443543643743843944044144244344444544644744844945045145245345445545645745845946046146246346446546646746846947047147247347447547647747847948048148248348448548648748848949049149249349449549649749849950050150250350450550650750850951051151251351451551651751851952052152252352452552652752852953053153253353453553653753853954054154254354454554654754854955055155255355455555655755855956056156256356456556656756856957057157257357457557657757857958058158258358458558658758858959059159259359459559659759859960060160260360460560660760860961061161261361461561661761861962062162262362462562662762862963063163263363463563663763863964064164264364464564664764864965065165265365465565665765865966066166266366466566666766866967067167267367467567667767867968068168268368468568668768868969069169269369469569669769869970070170270370470570670770870971071171271371471571671771871972072172272372472572672772872973073173273373473573673773873974074174274374474574674774874975075175275375475575675775875976076176276376476576676776876977077177277377477577677777877978078178278378478578678778878979079179279379479579679779879980080180280380480580680780880981081181281381481581681781881982082182282382482582682782882983083183283383483583683783883984084184284384484584684784884985085185285385485585685785885986086186286386486586686786886987087187287387487587687787887988088188288388488588688788888989089189289389489589689789889990090190290390490590690790890991091191291391491591691791891992092192292392492592692792892993093193293393493593693793893994094194294394494594694794894995095195295395495595695795895996096196296396496596696796896997097197297397497597697797897998098198298398498598698798898999099199299399499599699799899910001001100210031004100510061007100810091010101110121013101410151016101710181019102010211022102310241025(* This file is part of Luv, released under the MIT license. See LICENSE.md for
details, or visit https://github.com/aantron/luv/blob/master/LICENSE.md. *)(* Everything is in one file to cut down on Dune boilerplate, as it would grow
proportionally in the number of files the bindings are spread over.
https://github.com/ocaml/dune/issues/135. *)moduleDescriptions(F:Ctypes.TYPE)=structopenCtypesopenFmoduleError=structlete2big=constant"UV_E2BIG"intleteacces=constant"UV_EACCES"intleteaddrinuse=constant"UV_EADDRINUSE"intleteaddrnotavail=constant"UV_EADDRNOTAVAIL"intleteafnosupport=constant"UV_EAFNOSUPPORT"intleteagain=constant"UV_EAGAIN"intleteai_addrfamily=constant"UV_EAI_ADDRFAMILY"intleteai_again=constant"UV_EAI_AGAIN"intleteai_badflags=constant"UV_EAI_BADFLAGS"intleteai_badhints=constant"UV_EAI_BADHINTS"intleteai_canceled=constant"UV_EAI_CANCELED"intleteai_fail=constant"UV_EAI_FAIL"intleteai_family=constant"UV_EAI_FAMILY"intleteai_memory=constant"UV_EAI_MEMORY"intleteai_nodata=constant"UV_EAI_NODATA"intleteai_noname=constant"UV_EAI_NONAME"intleteai_overflow=constant"UV_EAI_OVERFLOW"intleteai_protocol=constant"UV_EAI_PROTOCOL"intleteai_service=constant"UV_EAI_SERVICE"intleteai_socktype=constant"UV_EAI_SOCKTYPE"intletealready=constant"UV_EALREADY"intletebadf=constant"UV_EBADF"intletebusy=constant"UV_EBUSY"intletecanceled=constant"UV_ECANCELED"intleteconnaborted=constant"UV_ECONNABORTED"intleteconnrefused=constant"UV_ECONNREFUSED"intleteconnreset=constant"UV_ECONNRESET"intletedestaddrreq=constant"UV_EDESTADDRREQ"intleteexist=constant"UV_EEXIST"intletefault=constant"UV_EFAULT"intletefbig=constant"UV_EFBIG"intleteftype=constant"UV_EFTYPE"intletehostunreach=constant"UV_EHOSTUNREACH"intleteilseq=constant"UV_EILSEQ"intleteintr=constant"UV_EINTR"intleteinval=constant"UV_EINVAL"intleteio=constant"UV_EIO"intleteisconn=constant"UV_EISCONN"intleteisdir=constant"UV_EISDIR"intleteloop=constant"UV_ELOOP"intletemfile=constant"UV_EMFILE"intletemsgsize=constant"UV_EMSGSIZE"intletenametoolong=constant"UV_ENAMETOOLONG"intletenetdown=constant"UV_ENETDOWN"intletenetunreach=constant"UV_ENETUNREACH"intletenfile=constant"UV_ENFILE"intletenobufs=constant"UV_ENOBUFS"intletenodata=constant"UV_ENODATA"intletenodev=constant"UV_ENODEV"intletenoent=constant"UV_ENOENT"intletenomem=constant"UV_ENOMEM"intletenonet=constant"UV_ENONET"intletenoprotoopt=constant"UV_ENOPROTOOPT"intletenospc=constant"UV_ENOSPC"intletenosys=constant"UV_ENOSYS"intletenotconn=constant"UV_ENOTCONN"intletenotdir=constant"UV_ENOTDIR"intletenotempty=constant"UV_ENOTEMPTY"intletenotsock=constant"UV_ENOTSOCK"intletenotsup=constant"UV_ENOTSUP"intletenotty=constant"UV_ENOTTY"intleteoverflow=constant"UV_EOVERFLOW"intleteperm=constant"UV_EPERM"intletepipe=constant"UV_EPIPE"intleteproto=constant"UV_EPROTO"intleteprotonosupport=constant"UV_EPROTONOSUPPORT"intleteprototype=constant"UV_EPROTOTYPE"intleterange=constant"UV_ERANGE"intleterofs=constant"UV_EROFS"intleteshutdown=constant"UV_ESHUTDOWN"intletesocktnosupport=constant"UV_ESOCKTNOSUPPORT"intletespipe=constant"UV_ESPIPE"intletesrch=constant"UV_ESRCH"intletetimedout=constant"UV_ETIMEDOUT"intletetxtbsy=constant"UV_ETXTBSY"intleteunatch=constant"UV_EUNATCH"intletexdev=constant"UV_EXDEV"intletunknown=constant"UV_UNKNOWN"intleteof=constant"UV_EOF"intletenxio=constant"UV_ENXIO"intletemlink=constant"UV_EMLINK"intendmoduleVersion=structletmajor=constant"UV_VERSION_MAJOR"intletminor=constant"UV_VERSION_MINOR"intletpatch=constant"UV_VERSION_PATCH"intletis_release=constant"UV_VERSION_IS_RELEASE"boollethex=constant"UV_VERSION_HEX"int(* UV_VERSION_SUFFIX cannot be bound as a constant, so it is bound as a
function returning that constant: C.Functions.Version.suffix. *)endmoduleLoop=structmoduleRun_mode=structletdefault=constant"UV_RUN_DEFAULT"int64_tletonce=constant"UV_RUN_ONCE"int64_tletnowait=constant"UV_RUN_NOWAIT"int64_ttypet=[|`DEFAULT|`ONCE|`NOWAIT]lett:ttyp=enum"uv_run_mode"~typedef:true[`DEFAULT,default;`ONCE,once;`NOWAIT,nowait;]endmoduleOption=structletblock_signal=constant"UV_LOOP_BLOCK_SIGNAL"intletsigprof=constant"SIGPROF"intletidle_time=constant"UV_METRICS_IDLE_TIME"intendtypet=[`Loop]structurelett:ttyp=typedef(structure"`Loop")"uv_loop_t"let()=sealtendmoduleMetrics=structtypet=[`Metrics]structurelett:ttyp=typedef(structure"`Metrics")"uv_metrics_t"letloop_count=fieldt"loop_count"uint64_tletevents=fieldt"events"uint64_tletevents_waiting=fieldt"events_waiting"uint64_tlet()=sealtendmoduleBuf=structtypet=[`Buf]structurelett:ttyp=typedef(structure"`Buf")"uv_buf_t"letbase=fieldt"base"(ptrchar)letlen=fieldt"len"size_tlet()=sealtendmoduleOs_fd=structtypet=[`Os_fd]structurelett:ttyp=typedef(structure"`Os_fd")"uv_os_fd_t"let()=sealtendmoduleOs_socket=structtypet=[`Os_socket]structurelett:ttyp=typedef(structure"`Os_socket")"uv_os_sock_t"let()=sealtendmoduleHandle=structmoduleType=structlettcp=constant"UV_TCP"intletnamed_pipe=constant"UV_NAMED_PIPE"intendtype'kindhandletype'kindt=('kindhandle)structurelett:([`Base]t)typ=typedef(structure"`Handle`")"uv_handle_t"let()=sealtletself_reference_index=constant"LUV_SELF_REFERENCE"intletgeneric_callback_index=constant"LUV_GENERIC_CALLBACK"intletclose_callback_index=constant"LUV_CLOSE_CALLBACK"intletdefault_reference_count=constant"LUV_HANDLE_REFERENCE_COUNT"intendmoduleRequest=structtype'kindrequesttype'kindt=('kindrequest)structurelett:([`Base]t)typ=typedef(structure"`Request")"uv_req_t"let()=sealtletdefault_reference_count=constant"LUV_MINIMUM_REFERENCE_COUNT"intendmoduleTimer=structlett:([`Timer]Handle.t)typ=typedef(structure"`Timer")"uv_timer_t"let()=sealtendmodulePrepare=structlett:([`Prepare]Handle.t)typ=typedef(structure"`Prepare")"uv_prepare_t"let()=sealtendmoduleCheck=structlett:([`Check]Handle.t)typ=typedef(structure"`Check")"uv_check_t"let()=sealtendmoduleIdle=structlett:([`Idle]Handle.t)typ=typedef(structure"`Idle")"uv_idle_t"let()=sealtendmoduleAsync=structlett:([`Async]Handle.t)typ=typedef(structure"`Async")"uv_async_t"let()=sealtendmodulePoll=structmoduleEvent=structletreadable=constant"UV_READABLE"intletwritable=constant"UV_WRITABLE"intletdisconnect=constant"UV_DISCONNECT"intletprioritized=constant"UV_PRIORITIZED"intendlett:([`Poll]Handle.t)typ=typedef(structure"`Poll")"uv_poll_t"let()=sealtendmoduleSignal=structlett:([`Signal]Handle.t)typ=typedef(structure"`Signal")"uv_signal_t"letsignum=fieldt"signum"intlet()=sealtmoduleSignum=structletsigabrt=constant"SIGABRT"intletsigfpe=constant"SIGFPE"intletsighup=constant"SIGHUP"intletsigill=constant"SIGILL"intletsigint=constant"SIGINT"intletsigkill=constant"SIGKILL"intletsigsegv=constant"SIGSEGV"intletsigterm=constant"SIGTERM"intletsigwinch=constant"SIGWINCH"intendendmoduleStream=structtype'kindt=[`Streamof'kind]Handle.tlett:([`Base]t)typ=typedef(structure"`Stream")"uv_stream_t"let()=sealtletsomaxconn=constant"SOMAXCONN"nativeintletreference_count=constant"LUV_STREAM_REFERENCE_COUNT"intletconnection_callback_index=constant"LUV_CONNECTION_CALLBACK"intletallocate_callback_index=constant"LUV_ALLOCATE_CALLBACK"intletstream=tmoduleConnect_request=structtypet=[`Connect]Request.tlett:ttyp=typedef(structure"`Connect")"uv_connect_t"lethandle=fieldt"handle"(ptrstream)let()=sealtendmoduleShutdown_request=structlett:([`Shutdown]Request.t)typ=typedef(structure"`Shutdown")"uv_shutdown_t"let()=sealtendmoduleWrite_request=structlett:([`Write]Request.t)typ=typedef(structure"`Write")"uv_write_t"let()=sealtendendmoduleAddress_family=structletunspec=constant"AF_UNSPEC"intletinet=constant"AF_INET"intletinet6=constant"AF_INET6"inttypet=[`Address_family]structurelett:ttyp=typedef(structure"`Address_family")"sa_family_t"let()=sealtendmoduleSockaddr=structtypet=[`Sockaddr]structurelett:ttyp=structure"sockaddr"let()=sealttypein_=[`Sockaddr_in]structureletin_:in_typ=structure"sockaddr_in"letsin_port=fieldin_"sin_port"ushortlet()=sealin_typein6=[`Sockaddr_in6]structureletin6:in6typ=structure"sockaddr_in6"letsin6_port=fieldin6"sin6_port"ushortlet()=sealin6typestorage=[`Sockaddr_storage]structureletstorage:storagetyp=structure"sockaddr_storage"letfamily=fieldstorage"ss_family"Address_family.tlet()=sealstorageendmoduleSocket_type=structletstream=constant"SOCK_STREAM"intletdgram=constant"SOCK_DGRAM"intletraw=constant"SOCK_RAW"intendmoduleTCP=structletipv6only=constant"UV_TCP_IPV6ONLY"intlett:([`TCP]Stream.t)typ=typedef(structure"`TCP")"uv_tcp_t"let()=sealtendmoduleFile=structmoduleRequest=structtypet=[`File]Request.tlett:ttyp=typedef(structure"`File")"uv_fs_t"let()=sealtend(* This should actually be an abstract type, but it is defined as int on
both Unix and Windows, so this definition is ok until Ctypes is
patched. *)typet=intlett:ttyp=intmoduleOpen_flag=structletrdonly=constant"UV_FS_O_RDONLY"intletwronly=constant"UV_FS_O_WRONLY"intletrdwr=constant"UV_FS_O_RDWR"intletcreat=constant"UV_FS_O_CREAT"intletexcl=constant"UV_FS_O_EXCL"intletexlock=constant"UV_FS_O_EXLOCK"intletnoctty=constant"UV_FS_O_NOCTTY"intletnofollow=constant"UV_FS_O_NOFOLLOW"intlettemporary=constant"UV_FS_O_TEMPORARY"intlettrunc=constant"UV_FS_O_TRUNC"intletappend=constant"UV_FS_O_APPEND"intletdirect=constant"UV_FS_O_DIRECT"intletdsync=constant"UV_FS_O_DSYNC"intletfilemap=constant"UV_FS_O_FILEMAP"intletnoatime=constant"UV_FS_O_NOATIME"intletnonblock=constant"UV_FS_O_NONBLOCK"intletrandom=constant"UV_FS_O_RANDOM"intletsequential=constant"UV_FS_O_SEQUENTIAL"intletshort_lived=constant"UV_FS_O_SHORT_LIVED"intletsymlink=constant"UV_FS_O_SYMLINK"intletsync=constant"UV_FS_O_SYNC"intendmoduleMode=structletirwxu=constant"S_IRWXU"intletirusr=constant"S_IRUSR"intletiwusr=constant"S_IWUSR"intletixusr=constant"S_IXUSR"intletirwxg=constant"S_IRWXG"intletirgrp=constant"S_IRGRP"intletiwgrp=constant"S_IWGRP"intletixgrp=constant"S_IXGRP"intletirwxo=constant"S_IRWXO"intletiroth=constant"S_IROTH"intletiwoth=constant"S_IWOTH"intletixoth=constant"S_IXOTH"intletisuid=constant"S_ISUID"intletisgid=constant"S_ISGID"intletisvtx=constant"S_ISVTX"intletifmt=constant"S_IFMT"intletifreg=constant"S_IFREG"intletifdir=constant"S_IFDIR"intletifblk=constant"S_IFBLK"intletifchr=constant"S_IFCHR"intletiflnk=constant"S_IFLNK"intletififo=constant"S_IFIFO"intendmoduleDirent=structmoduleKind=structletunknown=constant"UV_DIRENT_UNKNOWN"int64_tletfile=constant"UV_DIRENT_FILE"int64_tletdir=constant"UV_DIRENT_DIR"int64_tletlink=constant"UV_DIRENT_LINK"int64_tletfifo=constant"UV_DIRENT_FIFO"int64_tletsocket=constant"UV_DIRENT_SOCKET"int64_tletchar=constant"UV_DIRENT_CHAR"int64_tletblock=constant"UV_DIRENT_BLOCK"int64_ttypet=[|`UNKNOWN|`FILE|`DIR|`LINK|`FIFO|`SOCKET|`CHAR|`BLOCK]lett:ttyp=enum"uv_dirent_type_t"~typedef:true~unexpected:(fun_->`UNKNOWN)[`UNKNOWN,unknown;`FILE,file;`DIR,dir;`LINK,link;`FIFO,fifo;`SOCKET,socket;`CHAR,char;`BLOCK,block;]endtypet=[`Dirent]structurelett:ttyp=typedef(structure"`Dirent")"uv_dirent_t"letname=fieldt"name"stringlettype_=fieldt"type"Kind.tlet()=sealtendmoduleDir=structtypet=[`Dir]structurelett:ttyp=typedef(structure"`Dir")"uv_dir_t"letdirents=fieldt"dirents"(ptrDirent.t)letnentries=fieldt"nentries"size_tlet()=sealtendmoduleTimespec=structlett:([`Timespec]structure)typ=typedef(structure"`Timespec")"uv_timespec_t"lettv_sec=fieldt"tv_sec"longlettv_nsec=fieldt"tv_nsec"longlet()=sealtendmoduleStat=structtypet=[`Stat]structurelett:ttyp=typedef(structure"`Stat")"uv_stat_t"letst_dev=fieldt"st_dev"uint64_tletst_mode=fieldt"st_mode"uint64_tletst_nlink=fieldt"st_nlink"uint64_tletst_uid=fieldt"st_uid"uint64_tletst_gid=fieldt"st_gid"uint64_tletst_rdev=fieldt"st_rdev"uint64_tletst_ino=fieldt"st_ino"uint64_tletst_size=fieldt"st_size"uint64_tletst_blksize=fieldt"st_blksize"uint64_tletst_blocks=fieldt"st_blocks"uint64_tletst_flags=fieldt"st_flags"uint64_tletst_gen=fieldt"st_gen"uint64_tletst_atim=fieldt"st_atim"Timespec.tletst_mtim=fieldt"st_mtim"Timespec.tletst_ctim=fieldt"st_ctim"Timespec.tletst_birthtim=fieldt"st_birthtim"Timespec.tlet()=sealtendmoduleStatfs=structtypet=[`Statfs]structurelett:ttyp=typedef(structure"`Statfs")"uv_statfs_t"letf_type=fieldt"f_type"uint64_tletf_bsize=fieldt"f_bsize"uint64_tletf_blocks=fieldt"f_blocks"uint64_tletf_bfree=fieldt"f_bfree"uint64_tletf_bavail=fieldt"f_bavail"uint64_tletf_files=fieldt"f_files"uint64_tletf_ffree=fieldt"f_ffree"uint64_tletf_spare=fieldt"f_spare"(array4uint64_t)let()=sealtendmoduleCopy_flag=structletexcl=constant"UV_FS_COPYFILE_EXCL"intletficlone=constant"UV_FS_COPYFILE_FICLONE"intletficlone_force=constant"UV_FS_COPYFILE_FICLONE_FORCE"intendmoduleAccess_flag=structletf=constant"F_OK"intletr=constant"R_OK"intletw=constant"W_OK"intletx=constant"X_OK"intendmoduleSymlink_flag=structletdir=constant"UV_FS_SYMLINK_DIR"intletjunction=constant"UV_FS_SYMLINK_JUNCTION"intendendmodulePipe=structmoduleMode=structletreadable=Poll.Event.readableletwritable=Poll.Event.writableendlett:([`Pipe]Stream.t)typ=typedef(structure"`Pipe")"uv_pipe_t"let()=sealtletno_truncate=constant"UV_PIPE_NO_TRUNCATE"intendmoduleTTY=structmoduleMode=structletnormal=constant"UV_TTY_MODE_NORMAL"int64_tletraw=constant"UV_TTY_MODE_RAW"int64_tletio=constant"UV_TTY_MODE_IO"int64_ttypet=[|`NORMAL|`RAW|`IO]lett:ttyp=enum"uv_tty_mode_t"~typedef:true[`NORMAL,normal;`RAW,raw;`IO,io;]endmoduleVterm_state=structletsupported=constant"UV_TTY_SUPPORTED"int64_tletunsupported=constant"UV_TTY_UNSUPPORTED"int64_ttypet=[|`SUPPORTED|`UNSUPPORTED]lett:ttyp=enum"uv_tty_vtermstate_t"~typedef:true[`SUPPORTED,supported;`UNSUPPORTED,unsupported;]endlett:([`TTY]Stream.t)typ=typedef(structure"`TTY")"uv_tty_t"let()=sealtendmoduleUDP=structlett:([`UDP]Handle.t)typ=typedef(structure"`UDP")"uv_udp_t"let()=sealtletreference_count=constant"LUV_UDP_REFERENCE_COUNT"intletallocate_callback_index=constant"LUV_UDP_ALLOCATE_CALLBACK"intmoduleSend_request=structlett:([`Send]Request.t)typ=typedef(structure"`Send")"uv_udp_send_t"let()=sealtendmoduleFlag=structletipv6only=constant"UV_UDP_IPV6ONLY"intletpartial=constant"UV_UDP_PARTIAL"intletreuseaddr=constant"UV_UDP_REUSEADDR"intletmmsg_chunk=constant"UV_UDP_MMSG_CHUNK"intletmmsg_free=constant"UV_UDP_MMSG_FREE"intletrecvmmsg=constant"UV_UDP_RECVMMSG"intendmoduleMembership=structletleave_group=constant"UV_LEAVE_GROUP"int64_tletjoin_group=constant"UV_JOIN_GROUP"int64_ttypet=[|`LEAVE_GROUP|`JOIN_GROUP]lett:ttyp=enum"uv_membership"~typedef:true[`LEAVE_GROUP,leave_group;`JOIN_GROUP,join_group;]endendmoduleProcess=structlett:([`Process]Handle.t)typ=typedef(structure"`Process")"uv_process_t"let()=sealtmoduleFlag=structletsetuid=constant"UV_PROCESS_SETUID"intletsetgid=constant"UV_PROCESS_SETGID"intletwindows_verbatim_arguments=constant"UV_PROCESS_WINDOWS_VERBATIM_ARGUMENTS"intletdetached=constant"UV_PROCESS_DETACHED"intletwindows_hide=constant"UV_PROCESS_WINDOWS_HIDE"intletwindows_hide_console=constant"UV_PROCESS_WINDOWS_HIDE_CONSOLE"intletwindows_hide_gui=constant"UV_PROCESS_WINDOWS_HIDE_GUI"intletwindows_file_path_exact_name=constant"UV_PROCESS_WINDOWS_FILE_PATH_EXACT_NAME"intendmoduleRedirection=structtypet=[`Redirection]structurelett:ttyp=typedef(structure"`Redirection")"uv_stdio_container_t"letflags=fieldt"flags"intletstream=fieldt"data.stream"(ptrHandle.t)letfd=fieldt"data.fd"intlet()=sealtletignore=constant"UV_IGNORE"intletcreate_pipe=constant"UV_CREATE_PIPE"intletinherit_fd=constant"UV_INHERIT_FD"intletinherit_stream=constant"UV_INHERIT_STREAM"intletreadable_pipe=constant"UV_READABLE_PIPE"intletwritable_pipe=constant"UV_WRITABLE_PIPE"intletoverlapped_pipe=constant"UV_OVERLAPPED_PIPE"intendendmoduleFS_event=structlett:([`FS_event]Handle.t)typ=typedef(structure"`FS_event")"uv_fs_event_t"let()=sealtmoduleEvent=structletrename=constant"UV_RENAME"intletchange=constant"UV_CHANGE"intendmoduleFlag=structletwatch_entry=constant"UV_FS_EVENT_WATCH_ENTRY"intletstat=constant"UV_FS_EVENT_STAT"intletrecursive=constant"UV_FS_EVENT_RECURSIVE"intendendmoduleFS_poll=structlett:([`FS_poll]Handle.t)typ=typedef(structure"`FS_poll")"uv_fs_poll_t"let()=sealtendmoduleDNS=structmoduleAddr_info=structlett:([`Addrinfo]structure)typ=structure"addrinfo"letflags=fieldt"ai_flags"intletfamily=fieldt"ai_family"intletsocktype=fieldt"ai_socktype"intletprotocol=fieldt"ai_protocol"intletaddrlen=fieldt"ai_addrlen"intletaddr=fieldt"ai_addr"(ptrSockaddr.t)letcanonname=fieldt"ai_canonname"string_optletnext=fieldt"ai_next"(ptrt)let()=sealtmoduleRequest=structletunderlying=tlett:([`Addr_info]Request.t)typ=typedef(structure"`Addr_info")"uv_getaddrinfo_t"letaddrinfo=fieldt"addrinfo"(ptrunderlying)let()=sealtendmoduleFlag=structletpassive=constant"AI_PASSIVE"intletcanonname=constant"AI_CANONNAME"intletnumerichost=constant"AI_NUMERICHOST"intletnumericserv=constant"AI_NUMERICSERV"intletv4mapped=constant"AI_V4MAPPED"intletall=constant"AI_ALL"intletaddrconfig=constant"AI_ADDRCONFIG"intendendmoduleName_info=structlett:([`Name_info]Request.t)typ=typedef(structure"`Name_info")"uv_getnameinfo_t"lethost=fieldt"host"charletservice=fieldt"service"charlet()=sealtletmaxhost=constant"NI_MAXHOST"intletmaxserv=constant"NI_MAXSERV"intmoduleFlag=structletnamereqd=constant"NI_NAMEREQD"intletdgram=constant"NI_DGRAM"intletnofqdn=constant"NI_NOFQDN"intletnumerichost=constant"NI_NUMERICHOST"intletnumericserv=constant"NI_NUMERICSERV"intendendendmoduleDLL=structtypet=[`Lib]structurelett:ttyp=typedef(structure"`Lib")"uv_lib_t"let()=sealtendmoduleWork=structlett:([`Thread_pool]Request.t)typ=typedef(structure"`Thread_pool")"uv_work_t"let()=sealtletreference_count=constant"LUV_WORK_REFERENCE_COUNT"intletfunction_index=constant"LUV_WORK_FUNCTION"intendmoduleThread=structtypet=[`Thread]structurelett:ttyp=typedef(structure"`Thread")"uv_thread_t"let()=sealtmoduleOptions=structtypet=[`Thread_options]structurelett:ttyp=typedef(structure"`Thread_options")"uv_thread_options_t"letflags=fieldt"flags"intletstack_size=fieldt"stack_size"size_tlet()=sealtletno_flags=constant"UV_THREAD_NO_FLAGS"intlethas_stack_size=constant"UV_THREAD_HAS_STACK_SIZE"intendmodulePriority=structlethighest=constant"UV_THREAD_PRIORITY_HIGHEST"intletabove_normal=constant"UV_THREAD_PRIORITY_ABOVE_NORMAL"intletnormal=constant"UV_THREAD_PRIORITY_NORMAL"intletbelow_normal=constant"UV_THREAD_PRIORITY_BELOW_NORMAL"intletlowest=constant"UV_THREAD_PRIORITY_LOWEST"intendendmoduleTLS=structtypet=[`TLS]structurelett:ttyp=typedef(structure"`TLS")"uv_key_t"let()=sealtendmoduleOnce=structtypet=[`Once]structurelett:ttyp=typedef(structure"`Once")"uv_once_t"let()=sealtendmoduleMutex=structtypet=[`Mutex]structurelett:ttyp=typedef(structure"`Mutex")"uv_mutex_t"let()=sealtendmoduleRwlock=structtypet=[`Rwlock]structurelett:ttyp=typedef(structure"`Rwlock")"uv_rwlock_t"let()=sealtendmoduleSemaphore=structtypet=[`Semaphore]structurelett:ttyp=typedef(structure"`Semaphore")"uv_sem_t"let()=sealtendmoduleCondition=structtypet=[`Condition]structurelett:ttyp=typedef(structure"`Condition")"uv_cond_t"let()=sealtendmoduleBarrier=structtypet=[`Barrier]structurelett:ttyp=typedef(structure"`Barrier")"uv_barrier_t"let()=sealtendmoduleResource=structmodulePriority=structletlow=constant"UV_PRIORITY_LOW"intletbelow_normal=constant"UV_PRIORITY_BELOW_NORMAL"intletnormal=constant"UV_PRIORITY_NORMAL"intletabove_normal=constant"UV_PRIORITY_ABOVE_NORMAL"intlethigh=constant"UV_PRIORITY_HIGH"intlethighest=constant"UV_PRIORITY_HIGHEST"intendmoduleTimeval=structlett:([`Timeval]structure)typ=typedef(structure"`Timeval")"uv_timeval_t"letsec=fieldt"tv_sec"longletusec=fieldt"tv_usec"longlet()=sealtendmoduleRusage=structlett:([`Rusage]structure)typ=typedef(structure"`Rusage")"uv_rusage_t"letutime=fieldt"ru_utime"Timeval.tletstime=fieldt"ru_stime"Timeval.tletmaxrss=fieldt"ru_maxrss"uint64_tletixrss=fieldt"ru_ixrss"uint64_tletidrss=fieldt"ru_idrss"uint64_tletisrss=fieldt"ru_isrss"uint64_tletminflt=fieldt"ru_minflt"uint64_tletmajflt=fieldt"ru_majflt"uint64_tletnswap=fieldt"ru_nswap"uint64_tletinblock=fieldt"ru_inblock"uint64_tletoublock=fieldt"ru_oublock"uint64_tletmsgsnd=fieldt"ru_msgsnd"uint64_tletmsgrcv=fieldt"ru_msgrcv"uint64_tletnsignals=fieldt"ru_nsignals"uint64_tletnvcsw=fieldt"ru_nvcsw"uint64_tletnivcsw=fieldt"ru_nivcsw"uint64_tlet()=sealtendendmoduleCPU_info=structmoduleTimes=structlett:([`Times]structure)typ=structure"uv_cpu_times_s"letuser=fieldt"user"uint64_tletnice=fieldt"nice"uint64_tletsys=fieldt"sys"uint64_tletidle=fieldt"idle"uint64_tletirq=fieldt"irq"uint64_tlet()=sealtendlett:([`CPU_info]structure)typ=typedef(structure"`CPU_info")"uv_cpu_info_t"letmodel=fieldt"model"stringletspeed=fieldt"speed"intlettimes=fieldt"cpu_times"Times.tlet()=sealtendmoduleNetwork=structmoduleInterface_address=structlett:([`Interface_address]structure)typ=structure"uv_interface_address_s"letname=fieldt"name"stringletphys_addr=fieldt"phys_addr"(array6char)letis_internal=fieldt"is_internal"boolletaddress4=fieldt"address.address4"Sockaddr.in_letaddress6=fieldt"address.address6"Sockaddr.in6letnetmask4=fieldt"netmask.netmask4"Sockaddr.in_letnetmask6=fieldt"netmask.netmask6"Sockaddr.in6let()=sealtendletif_namesize=constant"UV_IF_NAMESIZE"intletmaxhostnamesize=constant"UV_MAXHOSTNAMESIZE"intendmodulePasswd=structlett:([`Passwd]structure)typ=typedef(structure"`Passwd")"uv_passwd_t"letusername=fieldt"username"stringletuid=fieldt"uid"ulongletgid=fieldt"gid"ulongletshell=fieldt"shell"string_optlethomedir=fieldt"homedir"stringlet()=sealtletgroup:([`Group]structure)typ=typedef(structure"`Group")"uv_group_t"letgroupname=fieldgroup"groupname"stringletgroup_gid=fieldgroup"gid"ulongletmembers=fieldgroup"members"(ptr(ptrchar))let()=sealgroupendmoduleTime=structmoduleTimeval=structlett:([`Timeval64]structure)typ=typedef(structure"`Timeval64")"uv_timeval64_t"letsec=fieldt"tv_sec"int64_tletusec=fieldt"tv_usec"int32_tlet()=sealtendmoduleTimespec=structlett:([`Timespec]structure)typ=typedef(structure"`Timespec64")"uv_timespec64_t"letsec=fieldt"tv_sec"int64_tletnsec=fieldt"tv_nsec"int32_tlet()=sealtletmonotonic=constant"UV_CLOCK_MONOTONIC"intletreal_time=constant"UV_CLOCK_REALTIME"intendendmoduleEnv_item=structlett:([`Env_item]structure)typ=typedef(structure"`Env_item")"uv_env_item_t"letname=fieldt"name"stringletvalue=fieldt"value"stringlet()=sealtendmoduleRandom=structmoduleRequest=structtypet=[`Random]Request.tlett:ttyp=typedef(structure"`Random")"uv_random_t"let()=sealtendendend