package luv

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Luv.VersionSource

Version information for the vendored libuv.

See Version-checking macros and functions in libuv.

Luv currently vendors libuv 1.30.1.

Sourceval string : unit -> string

Returns the libuv version as a string. See uv_version_string.

Sourceval major : int

libuv major version number. See UV_VERSION_MAJOR.

Sourceval minor : int

libuv minor version number. See UV_VERSION_MINOR.

Sourceval patch : int

libuv patch number. See UV_VERSION_PATCH.

Sourceval is_release : bool

true if the libuv version is a release, and false if it is a development version. This will almost always be true for Luv releases. See UV_VERSION_IS_RELEASE.

Sourceval suffix : string

libuv version suffix for development releases. See UV_VERSION_SUFFIX.

Sourceval hex : int

libuv version packed into a single integer. See UV_VERSION_HEX.

Sourceval version : unit -> int