Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Source file luv_c_type_descriptions.ml
123456789101112131415161718192021222324252627282930313233343536373839404142434445464748495051525354555657585960616263646566676869707172737475767778798081828384858687888990919293949596979899100101102103104105106107108109110111112113114115116117118119120121122123124125126127128129130131132133134135136137138139140141142143144145146147148149150151152153154155156157158159160161162163164165166167168169170171172173174175176177178179180181182183184185186187188189190191192193194195196197198199200201202203204205206207208209210211212213214215216217218219220221222223224225226227228229230231232233234235236237238239240241242243244245246247248249250251252253254255256257258259260261262263264265266267268269270271272273274275276277278279280281282283284285286287288289290291292293294295296297298299300301302303304305306307308309310311312313314315316317318319320321322323324325326327328329330331332333334335336337338339340341342343344345346347348349350351352353354355356357358359360361362363364365366367368369370371372373374375376377378379380381382383384385386387388389390391392393394395396397398399400401402403404405406407408409410411412413414415416417418419420421422423424425426427428429430431432433434435436437438439440441442443444445446447448449450451452453454455456457458459460461462463464465466467468469470471472473474475476477478479480481482483484485486487488489490491492493494495496497498499500501502503504505506507508509510511512513514515516517518519520521522523524525526527528529530531532533534535536537538539540541542543544545546547548549550551552553554555556557558559560561562563564565566567568569570571572573574575576577578579580581582583584585586587588589590591592593594595596597598599600601602603604605606607608609610611612613614615616617618619620621622623624625626627628629630631632633634635636637638639640641642643644645646647648649650651652653654655656657658659660661662663664665666667668669670671672673674675676677678679680681682683684685686687688689690691692693694695696697698699700701702703704705706707708709710711712713714715716717718719720721722723724725726727728729730731732733734735736737738739740741742743744745746747748749750751752753754755756757758759760761762763764765766767768769770771772773774775776777778779780781782783784785786787788789790791792793794795796797798799800801802803804805806807808809810811812813814815816817818819820821822823824825826827828829830831832833834835836837838839840841842843844845846847848849850851852853854855856857858859860861862863864865866867868869870871872873874875876877878879880881882883884885886887888889890891892893894895896897898899900901902903904905906907908909910911912913914915916917918919920921922923924925926927928929930931932933934935936937938939940941942943944945946947948949950951952(* This file is part of Luv, released under the MIT license. See LICENSE.md for
details, or visit https://github.com/aantron/luv/blob/master/LICENSE.md. *)(* Everything is in one file to cut down on Dune boilerplate, as it would grow
proportionally in the number of files the bindings are spread over.
https://github.com/ocaml/dune/issues/135. *)moduleDescriptions(F:Ctypes.TYPE)=structopenCtypesopenFmoduleError=structlete2big=constant"UV_E2BIG"intleteacces=constant"UV_EACCES"intleteaddrinuse=constant"UV_EADDRINUSE"intleteaddrnotavail=constant"UV_EADDRNOTAVAIL"intleteafnosupport=constant"UV_EAFNOSUPPORT"intleteagain=constant"UV_EAGAIN"intleteai_addrfamily=constant"UV_EAI_ADDRFAMILY"intleteai_again=constant"UV_EAI_AGAIN"intleteai_badflags=constant"UV_EAI_BADFLAGS"intleteai_badhints=constant"UV_EAI_BADHINTS"intleteai_canceled=constant"UV_EAI_CANCELED"intleteai_fail=constant"UV_EAI_FAIL"intleteai_family=constant"UV_EAI_FAMILY"intleteai_memory=constant"UV_EAI_MEMORY"intleteai_nodata=constant"UV_EAI_NODATA"intleteai_noname=constant"UV_EAI_NONAME"intleteai_overflow=constant"UV_EAI_OVERFLOW"intleteai_protocol=constant"UV_EAI_PROTOCOL"intleteai_service=constant"UV_EAI_SERVICE"intleteai_socktype=constant"UV_EAI_SOCKTYPE"intletealready=constant"UV_EALREADY"intletebadf=constant"UV_EBADF"intletebusy=constant"UV_EBUSY"intletecanceled=constant"UV_ECANCELED"intleteconnaborted=constant"UV_ECONNABORTED"intleteconnrefused=constant"UV_ECONNREFUSED"intleteconnreset=constant"UV_ECONNRESET"intletedestaddrreq=constant"UV_EDESTADDRREQ"intleteexist=constant"UV_EEXIST"intletefault=constant"UV_EFAULT"intletefbig=constant"UV_EFBIG"intletehostunreach=constant"UV_EHOSTUNREACH"intleteilseq=constant"UV_EILSEQ"intleteintr=constant"UV_EINTR"intleteinval=constant"UV_EINVAL"intleteio=constant"UV_EIO"intleteisconn=constant"UV_EISCONN"intleteisdir=constant"UV_EISDIR"intleteloop=constant"UV_ELOOP"intletemfile=constant"UV_EMFILE"intletemsgsize=constant"UV_EMSGSIZE"intletenametoolong=constant"UV_ENAMETOOLONG"intletenetdown=constant"UV_ENETDOWN"intletenetunreach=constant"UV_ENETUNREACH"intletenfile=constant"UV_ENFILE"intletenobufs=constant"UV_ENOBUFS"intletenodev=constant"UV_ENODEV"intletenoent=constant"UV_ENOENT"intletenomem=constant"UV_ENOMEM"intletenonet=constant"UV_ENONET"intletenoprotoopt=constant"UV_ENOPROTOOPT"intletenospc=constant"UV_ENOSPC"intletenosys=constant"UV_ENOSYS"intletenotconn=constant"UV_ENOTCONN"intletenotdir=constant"UV_ENOTDIR"intletenotempty=constant"UV_ENOTEMPTY"intletenotsock=constant"UV_ENOTSOCK"intletenotsup=constant"UV_ENOTSUP"intleteperm=constant"UV_EPERM"intletepipe=constant"UV_EPIPE"intleteproto=constant"UV_EPROTO"intleteprotonosupport=constant"UV_EPROTONOSUPPORT"intleteprototype=constant"UV_EPROTOTYPE"intleterange=constant"UV_ERANGE"intleterofs=constant"UV_EROFS"intleteshutdown=constant"UV_ESHUTDOWN"intletespipe=constant"UV_ESPIPE"intletesrch=constant"UV_ESRCH"intletetimedout=constant"UV_ETIMEDOUT"intletetxtbsy=constant"UV_ETXTBSY"intletexdev=constant"UV_EXDEV"intletunknown=constant"UV_UNKNOWN"intleteof=constant"UV_EOF"intletenxio=constant"UV_ENXIO"intletemlink=constant"UV_EMLINK"intendmoduleVersion=structletmajor=constant"UV_VERSION_MAJOR"intletminor=constant"UV_VERSION_MINOR"intletpatch=constant"UV_VERSION_PATCH"intletis_release=constant"UV_VERSION_IS_RELEASE"boollethex=constant"UV_VERSION_HEX"int(* UV_VERSION_SUFFIX cannot be bound as a constant, so it is bound as a
function returning that constant: C.Functions.Version.suffix. *)endmoduleLoop=structmoduleRun_mode=structletdefault=constant"UV_RUN_DEFAULT"int64_tletonce=constant"UV_RUN_ONCE"int64_tletnowait=constant"UV_RUN_NOWAIT"int64_ttypet=[|`DEFAULT|`ONCE|`NOWAIT]lett:ttyp=enum"uv_run_mode"~typedef:true[`DEFAULT,default;`ONCE,once;`NOWAIT,nowait;]endmoduleOption=structletblock_signal=constant"UV_LOOP_BLOCK_SIGNAL"intletsigprof=constant"SIGPROF"intendtypet=[`Loop]structurelett:ttyp=typedef(structure"`Loop")"uv_loop_t"let()=sealtendmoduleBuf=structtypet=[`Buf]structurelett:ttyp=typedef(structure"`Buf")"uv_buf_t"letbase=fieldt"base"(ptrchar)letlen=fieldt"len"uintlet()=sealtendmoduleOs_fd=structtypet=[`Os_fd]structurelett:ttyp=typedef(structure"`Os_fd")"uv_os_fd_t"let()=sealtendmoduleOs_socket=structtypet=[`Os_socket]structurelett:ttyp=typedef(structure"`Os_socket")"uv_os_sock_t"let()=sealtendmoduleHandle=structmoduleType=structlettcp=constant"UV_TCP"intletnamed_pipe=constant"UV_NAMED_PIPE"intendtype'kindhandletype'kindt=('kindhandle)structurelett:([`Base]t)typ=typedef(structure"`Handle`")"uv_handle_t"let()=sealtletself_reference_index=constant"LUV_SELF_REFERENCE"intletgeneric_callback_index=constant"LUV_GENERIC_CALLBACK"intletclose_callback_index=constant"LUV_CLOSE_CALLBACK"intletdefault_reference_count=constant"LUV_HANDLE_REFERENCE_COUNT"intendmoduleRequest=structtype'kindrequesttype'kindt=('kindrequest)structurelett:([`Base]t)typ=typedef(structure"`Request")"uv_req_t"let()=sealtletdefault_reference_count=constant"LUV_MINIMUM_REFERENCE_COUNT"intendmoduleTimer=structlett:([`Timer]Handle.t)typ=typedef(structure"`Timer")"uv_timer_t"let()=sealtendmodulePrepare=structlett:([`Prepare]Handle.t)typ=typedef(structure"`Prepare")"uv_prepare_t"let()=sealtendmoduleCheck=structlett:([`Check]Handle.t)typ=typedef(structure"`Check")"uv_check_t"let()=sealtendmoduleIdle=structlett:([`Idle]Handle.t)typ=typedef(structure"`Idle")"uv_idle_t"let()=sealtendmoduleAsync=structlett:([`Async]Handle.t)typ=typedef(structure"`Async")"uv_async_t"let()=sealtendmodulePoll=structmoduleEvent=structletreadable=constant"UV_READABLE"intletwritable=constant"UV_WRITABLE"intletdisconnect=constant"UV_DISCONNECT"intletprioritized=constant"UV_PRIORITIZED"intendlett:([`Poll]Handle.t)typ=typedef(structure"`Poll")"uv_poll_t"let()=sealtendmoduleSignal=structlett:([`Signal]Handle.t)typ=typedef(structure"`Signal")"uv_signal_t"letsignum=fieldt"signum"intlet()=sealtmoduleSignum=structletsigabrt=constant"SIGABRT"intletsigfpe=constant"SIGFPE"intletsighup=constant"SIGHUP"intletsigill=constant"SIGILL"intletsigint=constant"SIGINT"intletsigkill=constant"SIGKILL"intletsigsegv=constant"SIGSEGV"intletsigterm=constant"SIGTERM"intletsigwinch=constant"SIGWINCH"intendendmoduleStream=structtype'kindt=[`Streamof'kind]Handle.tlett:([`Base]t)typ=typedef(structure"`Stream")"uv_stream_t"let()=sealtletsomaxconn=constant"SOMAXCONN"intletreference_count=constant"LUV_STREAM_REFERENCE_COUNT"intletconnection_callback_index=constant"LUV_CONNECTION_CALLBACK"intletallocate_callback_index=constant"LUV_ALLOCATE_CALLBACK"intletstream=tmoduleConnect_request=structtypet=[`Connect]Request.tlett:ttyp=typedef(structure"`Connect")"uv_connect_t"lethandle=fieldt"handle"(ptrstream)let()=sealtendmoduleShutdown_request=structlett:([`Shutdown]Request.t)typ=typedef(structure"`Shutdown")"uv_shutdown_t"let()=sealtendmoduleWrite_request=structlett:([`Write]Request.t)typ=typedef(structure"`Write")"uv_write_t"let()=sealtendendmoduleSockaddr=structtypet=[`Sockaddr]structurelett:ttyp=structure"sockaddr"let()=sealttypein_=[`Sockaddr_in]structureletin_:in_typ=structure"sockaddr_in"letsin_port=fieldin_"sin_port"shortlet()=sealin_typein6=[`Sockaddr_in6]structureletin6:in6typ=structure"sockaddr_in6"letsin6_port=fieldin6"sin6_port"shortlet()=sealin6typestorage=[`Sockaddr_storage]structureletstorage:storagetyp=structure"sockaddr_storage"letfamily=fieldstorage"ss_family"shortlet()=sealstorageendmoduleAddress_family=structletunspec=constant"AF_UNSPEC"intletinet=constant"AF_INET"intletinet6=constant"AF_INET6"intendmoduleSocket_type=structletstream=constant"SOCK_STREAM"intletdgram=constant"SOCK_DGRAM"intletraw=constant"SOCK_RAW"intendmoduleTCP=structletipv6only=constant"UV_TCP_IPV6ONLY"intlett:([`TCP]Stream.t)typ=typedef(structure"`TCP")"uv_tcp_t"let()=sealtendmoduleFile=structmoduleRequest=structtypet=[`File]Request.tlett:ttyp=typedef(structure"`File")"uv_fs_t"let()=sealtend(* This should actually be an abstract type, but it is defined as int on
both Unix and Windows, so this definition is ok until Ctypes is
patched. *)typet=intlett:ttyp=intmoduleOpen_flag=structletrdonly=constant"UV_FS_O_RDONLY"intletwronly=constant"UV_FS_O_WRONLY"intletrdwr=constant"UV_FS_O_RDWR"intletcreat=constant"UV_FS_O_CREAT"intletexcl=constant"UV_FS_O_EXCL"intletexlock=constant"UV_FS_O_EXLOCK"intletnoctty=constant"UV_FS_O_NOCTTY"intletnofollow=constant"UV_FS_O_NOFOLLOW"intlettemporary=constant"UV_FS_O_TEMPORARY"intlettrunc=constant"UV_FS_O_TRUNC"intletappend=constant"UV_FS_O_APPEND"intletdirect=constant"UV_FS_O_DIRECT"intletdsync=constant"UV_FS_O_DSYNC"intletfilemap=constant"UV_FS_O_FILEMAP"intletnoatime=constant"UV_FS_O_NOATIME"intletnonblock=constant"UV_FS_O_NONBLOCK"intletrandom=constant"UV_FS_O_RANDOM"intletsequential=constant"UV_FS_O_SEQUENTIAL"intletshort_lived=constant"UV_FS_O_SHORT_LIVED"intletsymlink=constant"UV_FS_O_SYMLINK"intletsync=constant"UV_FS_O_SYNC"intendmoduleMode=structletirwxu=constant"S_IRWXU"intletirusr=constant"S_IRUSR"intletiwusr=constant"S_IWUSR"intletixusr=constant"S_IXUSR"intletirwxg=constant"S_IRWXG"intletirgrp=constant"S_IRGRP"intletiwgrp=constant"S_IWGRP"intletixgrp=constant"S_IXGRP"intletirwxo=constant"S_IRWXO"intletiroth=constant"S_IROTH"intletiwoth=constant"S_IWOTH"intletixoth=constant"S_IXOTH"intletisuid=constant"S_ISUID"intletisgid=constant"S_ISGID"intletisvtx=constant"S_ISVTX"intendmoduleDirent=structmoduleKind=structletunknown=constant"UV_DIRENT_UNKNOWN"int64_tletfile=constant"UV_DIRENT_FILE"int64_tletdir=constant"UV_DIRENT_DIR"int64_tletlink=constant"UV_DIRENT_LINK"int64_tletfifo=constant"UV_DIRENT_FIFO"int64_tletsocket=constant"UV_DIRENT_SOCKET"int64_tletchar=constant"UV_DIRENT_CHAR"int64_tletblock=constant"UV_DIRENT_BLOCK"int64_ttypet=[|`UNKNOWN|`FILE|`DIR|`LINK|`FIFO|`SOCKET|`CHAR|`BLOCK]lett:ttyp=enum"uv_dirent_type_t"~typedef:true~unexpected:(fun_->`UNKNOWN)[`UNKNOWN,unknown;`FILE,file;`DIR,dir;`LINK,link;`FIFO,fifo;`SOCKET,socket;`CHAR,char;`BLOCK,block;]endtypet=[`Dirent]structurelett:ttyp=typedef(structure"`Dirent")"uv_dirent_t"letname=fieldt"name"stringlettype_=fieldt"type"Kind.tlet()=sealtendmoduleDir=structtypet=[`Dir]structurelett:ttyp=typedef(structure"`Dir")"uv_dir_t"letdirents=fieldt"dirents"(ptrDirent.t)letnentries=fieldt"nentries"size_tlet()=sealtendmoduleTimespec=structlett:([`Timespec]structure)typ=typedef(structure"`Timespec")"uv_timespec_t"lettv_sec=fieldt"tv_sec"longlettv_nsec=fieldt"tv_nsec"longlet()=sealtendmoduleStat=structtypet=[`Stat]structurelett:ttyp=typedef(structure"`Stat")"uv_stat_t"letst_dev=fieldt"st_dev"uint64_tletst_mode=fieldt"st_mode"uint64_tletst_nlink=fieldt"st_nlink"uint64_tletst_uid=fieldt"st_uid"uint64_tletst_gid=fieldt"st_gid"uint64_tletst_rdev=fieldt"st_rdev"uint64_tletst_ino=fieldt"st_ino"uint64_tletst_size=fieldt"st_size"uint64_tletst_blksize=fieldt"st_blksize"uint64_tletst_blocks=fieldt"st_blocks"uint64_tletst_flags=fieldt"st_flags"uint64_tletst_gen=fieldt"st_gen"uint64_tletst_atim=fieldt"st_atim"Timespec.tletst_mtim=fieldt"st_mtim"Timespec.tletst_ctim=fieldt"st_ctim"Timespec.tletst_birthtim=fieldt"st_birthtim"Timespec.tlet()=sealtendmoduleStatfs=structtypet=[`Statfs]structurelett:ttyp=typedef(structure"`Statfs")"uv_statfs_t"letf_type=fieldt"f_type"uint64_tletf_bsize=fieldt"f_bsize"uint64_tletf_blocks=fieldt"f_blocks"uint64_tletf_bfree=fieldt"f_bfree"uint64_tletf_bavail=fieldt"f_bavail"uint64_tletf_files=fieldt"f_files"uint64_tletf_ffree=fieldt"f_ffree"uint64_tletf_spare=fieldt"f_spare"(array4uint64_t)let()=sealtendmoduleCopy_flag=structletexcl=constant"UV_FS_COPYFILE_EXCL"intletficlone=constant"UV_FS_COPYFILE_FICLONE"intletficlone_force=constant"UV_FS_COPYFILE_FICLONE_FORCE"intendmoduleAccess_flag=structletf=constant"F_OK"intletr=constant"R_OK"intletw=constant"W_OK"intletx=constant"X_OK"intendmoduleSymlink_flag=structletdir=constant"UV_FS_SYMLINK_DIR"intletjunction=constant"UV_FS_SYMLINK_JUNCTION"intendendmodulePipe=structmoduleMode=structletreadable=Poll.Event.readableletwritable=Poll.Event.writableendlett:([`Pipe]Stream.t)typ=typedef(structure"`Pipe")"uv_pipe_t"let()=sealtendmoduleTTY=structmoduleMode=structletnormal=constant"UV_TTY_MODE_NORMAL"int64_tletraw=constant"UV_TTY_MODE_RAW"int64_tletio=constant"UV_TTY_MODE_IO"int64_ttypet=[|`NORMAL|`RAW|`IO]lett:ttyp=enum"uv_tty_mode_t"~typedef:true[`NORMAL,normal;`RAW,raw;`IO,io;]endmoduleVterm_state=structletsupported=constant"UV_TTY_SUPPORTED"int64_tletunsupported=constant"UV_TTY_UNSUPPORTED"int64_ttypet=[|`SUPPORTED|`UNSUPPORTED]lett:ttyp=enum"uv_tty_vtermstate_t"~typedef:true[`SUPPORTED,supported;`UNSUPPORTED,unsupported;]endlett:([`TTY]Stream.t)typ=typedef(structure"`TTY")"uv_tty_t"let()=sealtendmoduleUDP=structlett:([`UDP]Handle.t)typ=typedef(structure"`UDP")"uv_udp_t"let()=sealtletreference_count=constant"LUV_UDP_REFERENCE_COUNT"intletallocate_callback_index=constant"LUV_UDP_ALLOCATE_CALLBACK"intmoduleSend_request=structlett:([`Send]Request.t)typ=typedef(structure"`Send")"uv_udp_send_t"let()=sealtendmoduleFlag=structletipv6only=constant"UV_UDP_IPV6ONLY"intletpartial=constant"UV_UDP_PARTIAL"intletreuseaddr=constant"UV_UDP_REUSEADDR"intletmmsg_chunk=constant"UV_UDP_MMSG_CHUNK"intendmoduleMembership=structletleave_group=constant"UV_LEAVE_GROUP"int64_tletjoin_group=constant"UV_JOIN_GROUP"int64_ttypet=[|`LEAVE_GROUP|`JOIN_GROUP]lett:ttyp=enum"uv_membership"~typedef:true[`LEAVE_GROUP,leave_group;`JOIN_GROUP,join_group;]endendmoduleProcess=structlett:([`Process]Handle.t)typ=typedef(structure"`Process")"uv_process_t"let()=sealtmoduleFlag=structletsetuid=constant"UV_PROCESS_SETUID"intletsetgid=constant"UV_PROCESS_SETGID"intletwindows_verbatim_arguments=constant"UV_PROCESS_WINDOWS_VERBATIM_ARGUMENTS"intletdetached=constant"UV_PROCESS_DETACHED"intletwindows_hide=constant"UV_PROCESS_WINDOWS_HIDE"intletwindows_hide_console=constant"UV_PROCESS_WINDOWS_HIDE_CONSOLE"intletwindows_hide_gui=constant"UV_PROCESS_WINDOWS_HIDE_GUI"intendmoduleRedirection=structtypet=[`Redirection]structurelett:ttyp=typedef(structure"`Redirection")"uv_stdio_container_t"letflags=fieldt"flags"intletstream=fieldt"data.stream"(ptrHandle.t)letfd=fieldt"data.fd"intlet()=sealtletignore=constant"UV_IGNORE"intletcreate_pipe=constant"UV_CREATE_PIPE"intletinherit_fd=constant"UV_INHERIT_FD"intletinherit_stream=constant"UV_INHERIT_STREAM"intletreadable_pipe=constant"UV_READABLE_PIPE"intletwritable_pipe=constant"UV_WRITABLE_PIPE"intletoverlapped_pipe=constant"UV_OVERLAPPED_PIPE"intendendmoduleFS_event=structlett:([`FS_event]Handle.t)typ=typedef(structure"`FS_event")"uv_fs_event_t"let()=sealtmoduleEvent=structletrename=constant"UV_RENAME"intletchange=constant"UV_CHANGE"intendmoduleFlag=structletwatch_entry=constant"UV_FS_EVENT_WATCH_ENTRY"intletstat=constant"UV_FS_EVENT_STAT"intletrecursive=constant"UV_FS_EVENT_RECURSIVE"intendendmoduleFS_poll=structlett:([`FS_poll]Handle.t)typ=typedef(structure"`FS_poll")"uv_fs_poll_t"let()=sealtendmoduleDNS=structmoduleAddr_info=structlett:([`Addrinfo]structure)typ=structure"addrinfo"letflags=fieldt"ai_flags"intletfamily=fieldt"ai_family"intletsocktype=fieldt"ai_socktype"intletprotocol=fieldt"ai_protocol"intletaddrlen=fieldt"ai_addrlen"intletaddr=fieldt"ai_addr"(ptrSockaddr.t)letcanonname=fieldt"ai_canonname"string_optletnext=fieldt"ai_next"(ptrt)let()=sealtmoduleRequest=structletunderlying=tlett:([`Addr_info]Request.t)typ=typedef(structure"`Addr_info")"uv_getaddrinfo_t"letaddrinfo=fieldt"addrinfo"(ptrunderlying)let()=sealtendmoduleFlag=structletpassive=constant"AI_PASSIVE"intletcanonname=constant"AI_CANONNAME"intletnumerichost=constant"AI_NUMERICHOST"intletnumericserv=constant"AI_NUMERICSERV"intletv4mapped=constant"AI_V4MAPPED"intletall=constant"AI_ALL"intletaddrconfig=constant"AI_ADDRCONFIG"intendendmoduleName_info=structlett:([`Name_info]Request.t)typ=typedef(structure"`Name_info")"uv_getnameinfo_t"lethost=fieldt"host"charletservice=fieldt"service"charlet()=sealtletmaxhost=constant"NI_MAXHOST"intletmaxserv=constant"NI_MAXSERV"intmoduleFlag=structletnamereqd=constant"NI_NAMEREQD"intletdgram=constant"NI_DGRAM"intletnofqdn=constant"NI_NOFQDN"intletnumerichost=constant"NI_NUMERICHOST"intletnumericserv=constant"NI_NUMERICSERV"intendendendmoduleDLL=structtypet=[`Lib]structurelett:ttyp=typedef(structure"`Lib")"uv_lib_t"let()=sealtendmoduleWork=structlett:([`Thread_pool]Request.t)typ=typedef(structure"`Thread_pool")"uv_work_t"let()=sealtletreference_count=constant"LUV_WORK_REFERENCE_COUNT"intletfunction_index=constant"LUV_WORK_FUNCTION"intendmoduleThread=structtypet=[`Thread]structurelett:ttyp=typedef(structure"`Thread")"uv_thread_t"let()=sealtmoduleOptions=structtypet=[`Thread_options]structurelett:ttyp=typedef(structure"`Thread_options")"uv_thread_options_t"letflags=fieldt"flags"intletstack_size=fieldt"stack_size"size_tlet()=sealtletno_flags=constant"UV_THREAD_NO_FLAGS"intlethas_stack_size=constant"UV_THREAD_HAS_STACK_SIZE"intendendmoduleTLS=structtypet=[`TLS]structurelett:ttyp=typedef(structure"`TLS")"uv_key_t"let()=sealtendmoduleOnce=structtypet=[`Once]structurelett:ttyp=typedef(structure"`Once")"uv_once_t"let()=sealtendmoduleMutex=structtypet=[`Mutex]structurelett:ttyp=typedef(structure"`Mutex")"uv_mutex_t"let()=sealtendmoduleRwlock=structtypet=[`Rwlock]structurelett:ttyp=typedef(structure"`Rwlock")"uv_rwlock_t"let()=sealtendmoduleSemaphore=structtypet=[`Semaphore]structurelett:ttyp=typedef(structure"`Semaphore")"uv_sem_t"let()=sealtendmoduleCondition=structtypet=[`Condition]structurelett:ttyp=typedef(structure"`Condition")"uv_cond_t"let()=sealtendmoduleBarrier=structtypet=[`Barrier]structurelett:ttyp=typedef(structure"`Barrier")"uv_barrier_t"let()=sealtendmoduleResource=structmoduleTimeval=structlett:([`Timeval]structure)typ=typedef(structure"`Timeval")"uv_timeval_t"letsec=fieldt"tv_sec"longletusec=fieldt"tv_usec"longlet()=sealtendmoduleRusage=structlett:([`Rusage]structure)typ=typedef(structure"`Rusage")"uv_rusage_t"letutime=fieldt"ru_utime"Timeval.tletstime=fieldt"ru_stime"Timeval.tletmaxrss=fieldt"ru_maxrss"uint64_tletixrss=fieldt"ru_ixrss"uint64_tletidrss=fieldt"ru_idrss"uint64_tletisrss=fieldt"ru_isrss"uint64_tletminflt=fieldt"ru_minflt"uint64_tletmajflt=fieldt"ru_majflt"uint64_tletnswap=fieldt"ru_nswap"uint64_tletinblock=fieldt"ru_inblock"uint64_tletoublock=fieldt"ru_oublock"uint64_tletmsgsnd=fieldt"ru_msgsnd"uint64_tletmsgrcv=fieldt"ru_msgrcv"uint64_tletnsignals=fieldt"ru_nsignals"uint64_tletnvcsw=fieldt"ru_nvcsw"uint64_tletnivcsw=fieldt"ru_nivcsw"uint64_tlet()=sealtendendmoduleCPU_info=structmoduleTimes=structlett:([`Times]structure)typ=structure"uv_cpu_times_s"letuser=fieldt"user"uint64_tletnice=fieldt"nice"uint64_tletsys=fieldt"sys"uint64_tletidle=fieldt"idle"uint64_tletirq=fieldt"irq"uint64_tlet()=sealtendlett:([`CPU_info]structure)typ=typedef(structure"`CPU_info")"uv_cpu_info_t"letmodel=fieldt"model"stringletspeed=fieldt"speed"intlettimes=fieldt"cpu_times"Times.tlet()=sealtendmoduleNetwork=structmoduleInterface_address=structlett:([`Interface_address]structure)typ=structure"uv_interface_address_s"letname=fieldt"name"stringletphys_addr=fieldt"phys_addr"(array6char)letis_internal=fieldt"is_internal"boolletaddress4=fieldt"address.address4"Sockaddr.in_letaddress6=fieldt"address.address6"Sockaddr.in6letnetmask4=fieldt"netmask.netmask4"Sockaddr.in_letnetmask6=fieldt"netmask.netmask6"Sockaddr.in6let()=sealtendletif_namesize=constant"UV_IF_NAMESIZE"intletmaxhostnamesize=constant"UV_MAXHOSTNAMESIZE"intendmodulePasswd=structlett:([`Passwd]structure)typ=typedef(structure"`Passwd")"uv_passwd_t"letusername=fieldt"username"stringletuid=fieldt"uid"longletgid=fieldt"gid"longletshell=fieldt"shell"string_optlethomedir=fieldt"homedir"stringlet()=sealtendmoduleTime=structmoduleTimeval=structlett:([`Timeval64]structure)typ=typedef(structure"`Timeval64")"uv_timeval64_t"letsec=fieldt"tv_sec"int64_tletusec=fieldt"tv_usec"int32_tlet()=sealtendendmoduleEnv_item=structlett:([`Env_item]structure)typ=typedef(structure"`Env_item")"uv_env_item_t"letname=fieldt"name"stringletvalue=fieldt"value"stringlet()=sealtendmoduleRandom=structmoduleRequest=structtypet=[`Random]Request.tlett:ttyp=typedef(structure"`Random")"uv_random_t"let()=sealtendendend